@@ -4,6 +4,7 @@ mod thread_pool;
 mod types;
 mod worker_pool;
 
-pub use self::single_worker::SingleWorker;
+pub use self::single_worker::blocking::SingleWorker;
+pub use self::single_worker::timeout::SingleWorkerTimeout;
 pub use self::thread_pool::{ExecuteError, ThreadPool};
 pub use self::worker_pool::{MessageSender, QueueError, WorkerPool};
